<?php
/*
-------------------------------------------------------------------------------
HitTrack - Version 1.0.03 - 23 Dec 2009
A simple hit counter plugin for LightNEasy 3.1+
Copyright (c) 2009 Scott Smith <scott@grimblefritz.com>
All rights reserved.

Hit counters are stored in plugins/hittrack/hits in text
files. Each file contains a single line with the number
of hits for the page file name that matches the filename
for the LNE page.

For example, if you have a contact page called 'Contact Us'
and the file is contact.php, then there will be a contact.txt
file to track its hits.

Global hits are tracked in GLOBAL_HITS.txt

If the system is in admin mode, hits are tracked separately
in files with '_admin' appended. For example, hits on the
contact page are in contact_admin.php and the global hits
are tracked in GLOBAL_HITS_admin.php
-------------------------------------------------------------------------------
*/

//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
// PLUGIN CONFIGURATION SETUP
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// load the config file (if it exists) and then check the
// config array and set defaults if it's not populated

function _Hit_Track_Init() {

$config['version'] = "1.0.03";
$config['release'] = "23 Dec 2009";
$config['home'] = 'plugins/hittrack';
$config['file'] = "$config[home]/config.php";

if (file_exists($config['file']))
  include_once $config['file'];

if (!isset($config['data']))
  $config['data'] = "$config[home]/data";

if (!isset($config['echo']))
  $config['echo'] = TRUE;

if (!isset($config['text']))
  $config['text'] = 'Page Hits : {count}';

return $config;

}

//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
// PLUGIN RUNTIME CODE
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------

function _Hit_Track() {

  global $LNEversion, $pagenum;

  $config = _Hit_Track_Init();

  // if we're in admin mode, don't track
  // hits in with the 'normal' page hits

  if ( isset($LNEversion) && ( function_exists('adminmenu') || $_GET['do'] == 'login' ) )
  {
    $admin = '_admin';
  } else {
    $admin = '';
  }

  // names for tracking files

  $pagefile = "$config[data]/$pagenum$admin.txt";
  $sitefile = "$config[data]/GLOBAL_HITS$admin.txt";

  if (!is_dir($config['data'])) {

    // bad news, data directory doesn't exist

    $count = 'ERROR';

  } else {

    // update site-wide hits
    if (file_exists($sitefile)) {
      $count = file_get_contents($sitefile) + 1;
    } else {
      $count = 1;
    }
    file_put_contents($sitefile, $count);

    // update page-level hits
    if (file_exists($pagefile)) {
      $count = file_get_contents($pagefile) + 1;
    } else {
      $count = 1;
    }
    file_put_contents($pagefile, $count);

  }

  // echo out the counter (unless suppressed)
  if ($config['echo'] !== FALSE)
    echo str_replace('{count}', $count, $config['text']);

}

//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
// GENERAL PURPOSE FUNCTIONS
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// file_put_contents() is a PHP5 function, so help out PHP4 users...

if (!function_exists('file_put_contents')) {
  function file_put_contents($filename, $data) {
    $f = @fopen($filename, 'w');
    if (!$f) {
      return false;
    } else {
      $bytes = fwrite($f, $data);
      fclose($f);
      return $bytes;
    }
  }
}

//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
// PLUGIN SETUP CODE
//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------

function _Hit_Track_Header() {
  return "<hr /><center><big><b>H i t &nbsp;&nbsp; T r a c k &nbsp;&nbsp; "
       . "A d m i n i s t r a t i o n</b></big></center>\n";
}

//-----------------------------------------------------------------------------

function _Hit_Track_Subheader($msg) {
  return "<center><b><i>&diams;&mdash; &nbsp; $msg &nbsp; &mdash;&diams;</i></b></center>\n";
}

//-----------------------------------------------------------------------------

function _Hit_Track_Footer(&$config) {
  return "<hr /><p align='center'>&nbsp;<br /><small><i>HitTrack "
       . "Version $config[version] - "
       . "Release $config[release]</i></small></p>\n";
}

//-----------------------------------------------------------------------------

function _Hit_Track_Info() {
return '/*
-------------------------------------------------------------------------------
HitTrack - a simple hit counter plugin for LightNEasy
HitTrack Module - config.php
Copyright (c) 2009 Scott Smith <scott@grimblefritz.com>
All rights reserved.
-------------------------------------------------------------------------------

Set the location of the HitTrack counter data files.
Note: make sure you create a writeable directory here!
DEFAULT: $config["data"] = "plugins/hittrack/data";

Set the text to be output for the hit counter - any
occurance of {count} will be replaced by the count
DEFAULT: $config["text"] = "Page Hits : {count}";

Set to FALSE to prevent HitTrack from displaying results.
DEFAULT: $config["echo"]= TRUE;

-------------------------------------------------------------------------------
*/
';
}

//-----------------------------------------------------------------------------

function _Hit_Track_Setup() {

  $config = _Hit_Track_Init();

  $out .= _Hit_Track_Header();

  if ($_POST['action'] == 'Save Setup')
    $out .= _Hit_Track_Save($config);

  if ($_POST['action'] == 'View Hits')
    $out .= _Hit_Track_View($config);
  else
    $out .= _Hit_Track_Edit($config);

  return $out . _Hit_Track_Footer($config);
}

//-----------------------------------------------------------------------------

function _Hit_Track_Edit(&$config) {

  $dataed = htmlentities(stripslashes($config['data']));
  $texted = htmlentities(stripslashes($config['text']));
  $checked = ($config['echo']) ? 'checked' : '';

  $datahelp = 'This is the directory where the hit files are stored. It should be a writable directory. It does not have to be located in the plugin directory, or even in the LNE directory tree. DEFAULT: ./plugins/hittrack/data';
  $texthelp = 'This is the text used to display the hit counter. It is inserted into the page as-is and may contain HTML code. The string {count} is replaced with the hit count. DEFAULT: Page Hits : {count}';
  $echohelp = 'This controls whether the counter is displayed or not. If disabled (unchecked), then the hit counters are maintained but they can only be viewed using the View Hits feature in this setup module. DEFAULT: enabled';

  return "
  <hr />
  <form method='POST' action=''>
  <table align='center' border='0'>
  <tr><td colspan='2'>&nbsp;</td></tr>
  <tr valign='top'>
    <td><label for='data' title='$datahelp'>Data Directory &nbsp;&nbsp;</title></td>
    <td><input type='text' name='data' size='50' title='$datahelp' value='$dataed' /></td>
  </tr>
  <tr><td colspan='2'>&nbsp;</td></tr>
  <tr valign='top'>
    <td><label for='text' title='$texthelp'>Output Format</title></td>
    <td><textarea name='text' rows='4' cols='40' title='$texthelp'>$texted</textarea></td>
  </tr>
  <tr><td colspan='2'>&nbsp;</td></tr>
  <tr valign='top'>
    <td><label for='echo' title='$echohelp'>Show Counter?</title></td>
    <td><input type='checkbox' name='echo' title='$echohelp' value='TRUE' $checked /></td>
  </tr>
  <tr><td colspan='2'>&nbsp;</td></tr>
  </table>
  <hr />
  <p align='center'>
  &nbsp;<br />
  <input type='submit' name='action' value='Save Setup' />
  &nbsp;&nbsp;&nbsp;
  <input type='submit' name='action' value='View Hits' />
  </p>
  </form>
  \n";

}

//-----------------------------------------------------------------------------

function _Hit_Track_Save(&$config) {

  $data = $_POST['data'];
  $text = $_POST['text'];
  $echo = ($_POST['echo'] == 'TRUE') ? 'TRUE' : 'FALSE';

  $new = "<?php\n"
       . _Hit_Track_Info()
       . "\$config['data'] = '$data';\n"
       . "\$config['text'] = '$text';\n"
       . "\$config['echo'] = $echo;\n"
       . "?>\n";

  $cfg = file_put_contents($config['file'], $new);

  if ($cfg !== FALSE) {
    $config['data'] = $data;
    $config['text'] = $text;
    $config['echo'] = ($echo == 'TRUE') ? TRUE : FALSE;
    $out = _Hit_Track_Subheader('Your setup has been saved.');
  } else {
    $out = _Hit_Track_Subheader('ERROR: Unable to save configuration!');
  }

  return $out;
}

//-----------------------------------------------------------------------------

function _Hit_Track_View(&$config) {

  global $menu;

  if (is_dir($config['data'])) {

    $n=0;
    foreach ($menu as $item) { $pages[$n++] = $item['page']; }
    sort($pages);
    $pages[$n++] = "GLOBAL_HITS";

    $out .= "
    <hr />
    <form method='POST' action=''>
    &nbsp;<br />
    <table align='center' border='1' cellpadding='4' cellspacing='0'>
    <tr>
      <td nowrap><b>&nbsp; PAGE NAME &nbsp;</b></tr>
      <td nowrap align='right'><b>&nbsp; NORMAL HITS &nbsp;</b></tr>
      <td nowrap align='right'><b>&nbsp; ADMIN HITS &nbsp;</b></tr>
    </tr>
    \n";

    foreach ($pages as $page) {
      $normal = "$config[data]/$page.txt";
      $admin = "$config[data]/${page}_admin.txt";
      if (file_exists($normal)) {
        $normal = file_get_contents($normal);
        if ($normal !== FALSE) {
          if ($page !== 'GLOBAL_HITS') $NTOTAL += $normal;
        } else {
          $normal = 'error';
        }
      } else {
        $normal='';
      }
      if (file_exists($admin)) {
        $admin = file_get_contents($admin);
        if ($admin !== FALSE) {
          if ($page !== 'GLOBAL_HITS') $ATOTAL += $admin;
        } else {
          $admin = 'error';
        }
      } else {
        $admin='';
      }
      $out .= "
      <tr>
      <td>&nbsp; $page &nbsp;</td>
      <td align='right'>&nbsp; $normal &nbsp;</td>
      <td align='right'>&nbsp; $admin &nbsp;</td>
      </tr>
      \n";
    }

    $out .= "
    <tr>
    <td>&nbsp; SUM TOTAL &nbsp;</td>
    <td align='right'>&nbsp; $NTOTAL &nbsp;</td>
    <td align='right'>&nbsp; $ATOTAL &nbsp;</td>
    </tr>
    </table>
    &nbsp;<br />
    \n";

  } else {
    $out = _Hit_Track_Subheader('ERROR: Data directory not found!');
  }

  $out .= "
  <hr />
  <p align='center'>
  &nbsp;<br />
  <input type='submit' name='action' value='Edit Setup' />
  &nbsp;&nbsp;&nbsp;
  <input type='submit' name='action' value='View Hits' />
  </p>
  </form>
  \n";

  return $out;

}

//-----------------------------------------------------------------------------
// EOF(hittrack.php)
//-----------------------------------------------------------------------------
?>
